@@ -16,7 +16,7 @@ import yaml
 
 
 # GLOBAL CONSTANTS
-__version__ = "1.2"
+__version__ = "1.2.1"
 __date__ = "Feb-2022"
 
 background = 0
@@ -446,13 +446,15 @@ def render_block(block, header_width, metrics, style, xoffset, yoffset=0, short_
     (lwd, xpadding, ypadding, threadoffset, linescaling) = style
 
     y_top = yoffset
-    out = ["", "", svg_text(5 + xpadding, y_top + lineheight, block["caption"], font_weight="bold"), yoffset + ypadding, 0]
+    # out = ["", "", svg_text(5 + xpadding, y_top + lineheight, block["caption"], font_weight="bold"), yoffset + ypadding, 0]
+    out = ["", "", svg_text(xpadding, y_top + lineheight, block["caption"], font_weight="bold"), yoffset + ypadding, 0]
 
     for thd in block["threads"]:
         out = add_rendering(out, render_thread, thd, metrics, style, xoffset, short_date=short_date)
     out[-2] += ypadding
     y_bottom = out[-2]
-    out[background] = svg_rect(5, y_top, header_width-5, y_bottom-y_top, lwd=0, fill_color=colors[block["color"]], fill_opacity=0.4)
+    # out[background] = svg_rect(5, y_top, header_width-5, y_bottom-y_top, lwd=0, fill_color=colors[block["color"]], fill_opacity=0.4)
+    out[background] = svg_rect(0, y_top, header_width, y_bottom-y_top, lwd=0, fill_color=colors[block["color"]], fill_opacity=0.4)
     out[-2] += ypadding
     return(out)
 
@@ -498,8 +500,10 @@ def render_tl(tl, fontsize=14, font="Arial", monthwidth=1, today=False, autowidt
     max_thread_caption_width = max([textwidth_function(t["caption"]) for b in tl["blocks"] for t in b["threads"]])
     threadoffset = max_block_caption_width/3 + 2 * xpadding
 
-    xoffset = 5 + max_block_caption_width/3 + max_thread_caption_width + xpadding * 4
-    yoffset = 5
+    # xoffset = 5 + max_block_caption_width/3 + max_thread_caption_width + xpadding * 4
+    xoffset = max_block_caption_width/3 + max_thread_caption_width + xpadding * 4
+    # yoffset = 5
+    yoffset = 0
     lwd = 1.5 * linescaling
 
     # Date limits
@@ -517,7 +521,7 @@ def render_tl(tl, fontsize=14, font="Arial", monthwidth=1, today=False, autowidt
 
     month_width = 30 * monthwidth
     if autowidth:
-        month_width = (1200 * .96-xoffset) / len(month_between(min_scale_date, max_scale_date))
+        month_width = (1200 -xoffset) / len(month_between(min_scale_date, max_scale_date))
 
     def date_position_function(d):
         month_x = month_difference(min_scale_date, d) * month_width
